@@ -35,12 +35,14 @@ def quote_id_for_url(item_id):
 # IS-10192: from https://carsonip.me/posts/azure-tcp-idle-timeout-tcp-keepalive-python/
 class HTTPAdapterWithSocketOptions(requests.adapters.HTTPAdapter):
     def __init__(self, *args, **kwargs):
-        self.socket_options = kwargs.pop("socket_options", None)
+        if "socket_options" in kwargs:
+            self.socket_options = kwargs.pop("socket_options", None)
         super(HTTPAdapterWithSocketOptions, self).__init__(*args, **kwargs)
 
     def init_poolmanager(self, *args, **kwargs):
         if self.socket_options is not None:
             kwargs["socket_options"] = self.socket_options
+
         super(HTTPAdapterWithSocketOptions, self).init_poolmanager(*args, **kwargs)
 
 
@@ -54,17 +56,26 @@ class HTTPAdapterWithTCPKeepalive(HTTPAdapterWithSocketOptions):
         # net.ipv4.tcp_keepalive_time = 180
         # net.ipv4.tcp_keepalive_intvl = 15
         # net.ipv4.tcp_keepalive_probes = 5
+
+        TCP_KEEPIDLE = 180
+        TCP_KEEPINTVL = 15
+        TCP_KEEPCNT = 5
+
         if getattr(socket, 'TCP_KEEPINTVL', None) is not None:
-            self.socket_options += [(socket.IPPROTO_TCP, socket.TCP_KEEPINTVL, 15)]
+            self.socket_options += [(socket.IPPROTO_TCP, socket.TCP_KEEPINTVL, TCP_KEEPINTVL)]
         elif sys.platform == 'darwin':
             TCP_KEEPALIVE = getattr(socket, 'TCP_KEEPALIVE', 0x10)
-            self.socket_options += [(socket.IPPROTO_TCP, TCP_KEEPALIVE, 15)]
+            self.socket_options += [(socket.IPPROTO_TCP, TCP_KEEPALIVE, TCP_KEEPINTVL)]
 
         if getattr(socket, 'TCP_KEEPCNT', None) is not None:
-            self.socket_options += [(socket.IPPROTO_TCP, socket.TCP_KEEPCNT, 5)]
+            self.socket_options += [(socket.IPPROTO_TCP, socket.TCP_KEEPCNT, TCP_KEEPCNT)]
 
         if getattr(socket, 'TCP_KEEPIDLE', None) is not None:
-            self.socket_options += [(socket.IPPROTO_TCP, socket.TCP_KEEPIDLE, 180)]
+            self.socket_options += [(socket.IPPROTO_TCP, socket.TCP_KEEPIDLE, TCP_KEEPIDLE)]
+
+        # See https://blog.cloudflare.com/when-tcp-sockets-refuse-to-die/
+        #if getattr(socket, 'TCP_USER_TIMEOUT', None) is not None:
+        #    self.socket_options += [(socket.IPPROTO_TCP, socket.TCP_USER_TIMEOUT, TCP_KEEPIDLE + TCP_KEEPINTVL * TCP_KEEPCNT)]
 
         super(HTTPAdapterWithTCPKeepalive, self).__init__(*args, **kwargs)
 
