@@ -44,10 +44,10 @@ class Pump(EntityBase):
         result += "\n    pipe_id:%r" % (self.pipe_id,)
         return result
 
-    def get_is_running(self):
+    def get_is_running(self, **kwargs):
         # Note: we must retrieve up-to-date information from the server, since the runtime stuff is so
         #       dynamic.
-        self.update_raw_jsondata_from_url(self._connection.get_pipe_pump_url(self.pipe_id))
+        self.update_raw_jsondata_from_url(self._connection.get_pipe_pump_url(self.pipe_id), **kwargs)
         return self._raw_jsondata["runtime"]["is-running"]
 
     def update_raw_jsondata(self, new_raw_jsondata):
@@ -58,7 +58,7 @@ class Pump(EntityBase):
         if "runtime" in self._raw_jsondata:
             self.pipe._raw_jsondata["runtime"].update(self._raw_jsondata["runtime"])
 
-    def wait_for_pump_to_finish_running(self, timeout=60, poll_interval=0.5, verbosity=0):
+    def wait_for_pump_to_finish_running(self, timeout=60, poll_interval=0.5, verbosity=0, **kwargs):
         """Utility method for waiting until the pump is no longer running. This is useful in
         integration tests that want to make sure that the pump has been run after the test-code has
         modified the data in the source-system of a pipe.
@@ -75,7 +75,7 @@ class Pump(EntityBase):
 
             elapsedtime = time.monotonic() - starttime
             if elapsedtime > timeout:
-                self.pipe.update_raw_jsondata_from_url(self._connection.get_pipe_url(self.pipe.id))
+                self.pipe.update_raw_jsondata_from_url(self._connection.get_pipe_url(self.pipe.id), **kwargs)
                 raise TimeoutWhileWaitingForRunningPumpToFinishException(
                     "Timed out while waiting for the pump to finish running! pipe:\n%s" % (
                         self.pipe.as_json(),
